intelmq.bots.experts.misp package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.experts.misp package

## Submodules

## intelmq.bots.experts.misp.expert module

An expert to for looking up values in MISP.

param - misp_url

  URL of the MISP server

param - misp_key

  API key for accessing MISP

param - http_verify_cert

  true or false, check the validity of the certificate

intelmq.bots.experts.misp.expert.BOT

  alias of `intelmq.bots.experts.misp.expert.MISPExpertBot`

class intelmq.bots.experts.misp.expert.MISPExpertBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ExpertBot`

  Looking up the IP address in MISP instance and retrieve attribute and event UUIDs

  init()
  misp_key: str = '<insert MISP Authkey>'
  misp_url: str = "<insert url of MISP server (with trailing '/')>"
  process()

## Module contents